/* Target-dependent code for the Renesas RX for GDB, the GNU debugger.

   Copyright (C) 2008-2015 Free Software Foundation, Inc.

   Contributed by Red Hat, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include "defs.h"
#include "arch-utils.h"
#include "prologue-value.h"
#include "target.h"
#include "regcache.h"
#include "opcode/green_dsp.h"
#include "dis-asm.h"
#include "gdbtypes.h"
#include "frame.h"
#include "frame-unwind.h"
#include "frame-base.h"
#include "value.h"
#include "gdbcore.h"
//#include "dwarf2\frame.h"
#include "target-descriptions.h"

#include "elf/rx.h"
#include "elf-bfd.h"

/* Certain important register numbers.  */
enum
{
  GREEN_DSP_V2_A0,
  GREEN_DSP_V2_M0,
  GREEN_DSP_V2_M1,
  GREEN_DSP_V2_L0,
  GREEN_DSP_V2_L1,
  GREEN_DSP_V2_R0,
  GREEN_DSP_V2_DP0,
  GREEN_DSP_V2_DP1,
  GREEN_DSP_V2_RP0,
  GREEN_DSP_V2_DSPCNT,
  GREEN_DSP_V2_PG0,
  GREEN_DSP_V2_DSPFLG,
  GREEN_DSP_V2_SYSC,
  GREEN_DSP_V2_SP0,
  GREEN_DSP_V2_NUM_REGS
};

enum
{
  GREEN_DSP_V3_A0,
  GREEN_DSP_V3_M0,
  GREEN_DSP_V3_M1,
  GREEN_DSP_V3_L0,
  GREEN_DSP_V3_L1,
  GREEN_DSP_V3_R0,
  GREEN_DSP_V3_DP0,
  GREEN_DSP_V3_DP1,
  GREEN_DSP_V3_RP0,
  GREEN_DSP_V3_INPCNT,
  GREEN_DSP_V3_PG0,
  GREEN_DSP_V3_INPFLG,
  GREEN_DSP_V3_R1,
  GREEN_DSP_V3_SYSC,
  GREEN_DSP_V3_F0,
  GREEN_DSP_V3_SP0,
  GREEN_DSP_V3_NUM_REGS
};

/* Architecture specific data.  */
struct green_dsp_gdbarch_tdep : gdbarch_tdep
{
  /* The ELF header flags specify the multilib used.  */
  int elf_flags;
};

extern int green_dsp_core_version;
GREEN_DSP_Core_Type green_dsp_core_type = GREEN_DSP_v2_type;

/* Implement the "register_name" gdbarch method.  */
static const char *
green_dsp_register_name (struct gdbarch *gdbarch, int regnr)
{
  static const char *const reg_names_v2[] = {
	"A0",
	"M0",
	"M1",
	"L0",
	"L1",
	"R0",
	"DP0",
	"DP1",
	"RP0",
	"DSPCNT",
	"PG0",
	"DSPFLG",
	"SYSC",
	"SP0",
  };
  
  static const char *const reg_names_faa[] = {
	"A0",
	"M0",
	"M1",
	"L0",
	"L1",
	"R0",
	"DP0",
	"DP1",
	"RP0",
	"FAACNT",
	"PG0",
	"FAAFLG",
	"SYSC",
	"SP0",
  };
  
  static const char *const reg_names_v3[] = {
	"A0",
	"M0",
	"M1",
	"L0",
	"L1",
	"R0",
	"DP0",
	"DP1",
	"RP0",
	"INPCNT",
	"PG0",
	"INPFLG",
	"R1",
	"SYSC",
	"F0",
	"SP0",
  };

  switch(green_dsp_core_type)
  {
	case GREEN_DSP_v2_type:
	  return reg_names_v2[regnr];
	case GREEN_DSP_faa_type:
	  return reg_names_faa[regnr];
    case GREEN_DSP_v3_type:
	  return reg_names_v3[regnr];
	default:
	  return "";
  }
}

int green_dsp_pc_register();

int green_dsp_pc_register()
{
  switch(green_dsp_core_type)
  {
  case GREEN_DSP_v2_type:
  case GREEN_DSP_faa_type:
    return GREEN_DSP_V2_PG0;
  case GREEN_DSP_v3_type:
	return GREEN_DSP_V3_PG0;  
  }
  return -1;
}

/* Implement the "register_type" gdbarch method.  */
static struct type *
green_dsp_register_type (struct gdbarch *gdbarch, int reg_nr)
{
  if (reg_nr == green_dsp_pc_register())
    return builtin_type (gdbarch)->builtin_func_ptr;
  else
    return builtin_type (gdbarch)->builtin_unsigned_long;
}


/* Define a "handle" struct for fetching the next opcode.  */
struct green_dsp_get_opcode_byte_handle
{
  CORE_ADDR pc;
};

// /* Fetch a byte on behalf of the opcode decoder.  HANDLE contains
   // the memory address of the next byte to fetch.  If successful,
   // the address in the handle is updated and the byte fetched is
   // returned as the value of the function.  If not successful, -1
   // is returned.  */
// static int
// green_dsp_get_opcode_byte (void *handle);

// static int
// green_dsp_get_opcode_byte (void *handle)
// {
  // struct rx_get_opcode_byte_handle *opcdata = 
    // (struct rx_get_opcode_byte_handle *)handle;
  // int status;
  // gdb_byte byte;

  // status = target_read_memory (opcdata->pc, &byte, 1);
  // if (status == 0)
    // {
      // opcdata->pc += 1;
      // return byte;
    // }
  // else
    // return -1;
// }

/* Implement the "skip_prologue" gdbarch method.  */
static CORE_ADDR
green_dsp_skip_prologue (struct gdbarch *gdbarch, CORE_ADDR pc)
{
  return pc;
}

/* Implement the "breakpoint_from_pc" gdbarch method.  */
static const gdb_byte *
green_dsp_breakpoint_from_pc (struct gdbarch *gdbarch, CORE_ADDR *pcptr, int *lenptr)
{
  //error (_("Green dsp does not support SW breakpoints"));
  return NULL;
}

static CORE_ADDR
green_dsp_unwind_pc (struct gdbarch *gdbarch, struct frame_info *this_frame)
{
  return frame_unwind_register_unsigned (this_frame, green_dsp_pc_register());
}

/* Implement the "frame_this_id" method for unwinding frames.  */
static void
green_dsp_frame_this_id (struct frame_info *this_frame,
		  void **this_prologue_cache, struct frame_id *this_id)
{

  /*this_id = frame_id_build (rx_frame_base (this_frame, this_prologue_cache),
			     get_frame_func (this_frame));*/
	//printf("green_dsp_frame_this_id\n");
	*this_id = frame_id_build_unavailable_stack_special (0xFFF11000,
			0xFFF11000);
}

/* Implement the "frame_prev_register" method for unwinding frames.  */
static struct value *
green_dsp_frame_prev_register (struct frame_info *this_frame,
			void **this_prologue_cache, int regnum)
{
    return frame_unwind_got_register (this_frame, regnum, regnum);
}

static const struct frame_unwind green_dsp_frame_unwind = {
  "green dsp",
  NORMAL_FRAME,
  default_frame_unwind_stop_reason,
  green_dsp_frame_this_id,
  green_dsp_frame_prev_register,
  NULL,
  default_frame_sniffer
};

static int
green_dsp_memory_breakpoint (struct gdbarch *gdbarch, struct bp_target_info *bp_tgt)
{
	error (_("Green dsp does not support SW breakpoints"));
	return 0;
}

/* We don't have SW breakpoint in green dsp 
  however GDB requires breakpoint_kind_from_pc  */
constexpr gdb_byte green_dsp_break_insn[] = { 0x00 };

typedef BP_MANIPULATION (green_dsp_break_insn) green_dsp_breakpoint;

/* Allocate and initialize a gdbarch object.  */
static struct gdbarch *
green_dsp_gdbarch_init (struct gdbarch_info info, struct gdbarch_list *arches)
{
  struct gdbarch *gdbarch;
  struct green_dsp_gdbarch_tdep *tdep;
  int elf_flags;
  const struct target_desc *tdesc = info.target_desc;
  tdesc_arch_data_up tdesc_data = NULL;
  //TODO: update this
  if((green_dsp_core_version < 2) || (green_dsp_core_version > 3))
  {
	error(_("Invalid green dsp core version"));
  }
  green_dsp_core_type = (GREEN_DSP_Core_Type)(green_dsp_core_version - 2);

  /* Extract the elf_flags if available.  */
  if (info.abfd != NULL
      && bfd_get_flavour (info.abfd) == bfd_target_elf_flavour)
    elf_flags = elf_elfheader (info.abfd)->e_flags;
  else
    elf_flags = 0;


  /* Try to find the architecture in the list of already defined
     architectures.  */
  for (arches = gdbarch_list_lookup_by_info (arches, &info);
       arches != NULL;
       arches = gdbarch_list_lookup_by_info (arches->next, &info))
    {
      tdep = (green_dsp_gdbarch_tdep *)gdbarch_tdep (arches->gdbarch);
      if (tdep->elf_flags != elf_flags)
	continue;

      return arches->gdbarch;
    }

  /* None found, create a new architecture from the information
     provided.  */
  tdep = (struct green_dsp_gdbarch_tdep *) xmalloc (sizeof (struct green_dsp_gdbarch_tdep));
  gdbarch = gdbarch_alloc (&info, tdep);
  tdep->elf_flags = elf_flags;

  if (tdesc_has_registers (tdesc)) {
	const struct tdesc_feature *feature;
    int valid_p = 1;

    feature = tdesc_find_feature (tdesc, "org.gnu.gdb.green-dsp.core-v2");
	if (feature == NULL) {
	  feature = tdesc_find_feature (tdesc, "org.gnu.gdb.green-dsp.core-faa");
	  if (feature == NULL) {
		feature = tdesc_find_feature (tdesc, "org.gnu.gdb.green-dsp.core-v3");
		if (feature == NULL)
		  return NULL;
		else
		  green_dsp_core_type = GREEN_DSP_v3_type;
	  }
	  else
		green_dsp_core_type = GREEN_DSP_faa_type;
	}

    tdesc_data = tdesc_data_alloc ();
	
    /* A0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_A0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_A0));
	/* M0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_M0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_M0));
	/* M1 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_M1,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_M1));
	/* L0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_L0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_L0));
	/* L1 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_L1,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_L1));
	/* R0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_R0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_R0));
	/* DP0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_DP0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_DP0));
	/* DP1 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_DP1,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_DP1));
	/* RP0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_RP0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_RP0));
	/* INPCNT/DSPCNT/FAACNT */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_INPCNT,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_INPCNT));
	/* PG0 */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_PG0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_PG0));
	/* INPFLG/DSPFLG/FAAFLG */
	valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_INPFLG,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_INPFLG));
		
	if (green_dsp_core_type == GREEN_DSP_v3_type) {
	  /* R1 */
	  valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_R1,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_R1));
	  /* SYSC */
	  valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_SYSC,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_SYSC));
      /* R1 */
	  valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_F0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_F0));
	  /* SP0 */
	  valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V3_SP0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V3_SP0));
	}
	else {
	  /* SYSC */
	  valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V2_SYSC,
		green_dsp_register_name(gdbarch, GREEN_DSP_V2_SYSC));
	  /* SP0 */
	  valid_p &= tdesc_numbered_register (feature, tdesc_data.get(), GREEN_DSP_V2_SP0,
		green_dsp_register_name(gdbarch, GREEN_DSP_V2_SP0));
	}

	if (!valid_p)
	  return NULL;
	
  }

  set_gdbarch_num_pseudo_regs (gdbarch, 0);
  set_gdbarch_register_name (gdbarch, green_dsp_register_name);
  set_gdbarch_register_type (gdbarch, green_dsp_register_type);
  set_gdbarch_inner_than (gdbarch, core_addr_lessthan);
  set_gdbarch_skip_prologue (gdbarch, green_dsp_skip_prologue);
  set_gdbarch_breakpoint_kind_from_pc (gdbarch, green_dsp_breakpoint::kind_from_pc);
  set_gdbarch_breakpoint_from_pc (gdbarch, green_dsp_breakpoint_from_pc);
  set_gdbarch_memory_insert_breakpoint (gdbarch, green_dsp_memory_breakpoint);
  set_gdbarch_memory_remove_breakpoint (gdbarch, green_dsp_memory_breakpoint);

  set_gdbarch_unwind_pc (gdbarch, green_dsp_unwind_pc);
  frame_unwind_append_unwinder (gdbarch, &green_dsp_frame_unwind);

  switch(green_dsp_core_type)
  {
  case GREEN_DSP_v2_type:
  case GREEN_DSP_faa_type:
    set_gdbarch_num_regs (gdbarch, GREEN_DSP_V2_NUM_REGS);
    set_gdbarch_pc_regnum (gdbarch, GREEN_DSP_V2_PG0);
	set_gdbarch_sp_regnum (gdbarch, GREEN_DSP_V2_SP0);
	set_gdbarch_print_insn (gdbarch, print_insn_green_dsp_v2);
	break;
  case GREEN_DSP_v3_type:
    set_gdbarch_num_regs (gdbarch, GREEN_DSP_V3_NUM_REGS);
    set_gdbarch_pc_regnum (gdbarch, GREEN_DSP_V3_PG0);
	set_gdbarch_sp_regnum (gdbarch, GREEN_DSP_V3_SP0);  
    set_gdbarch_print_insn (gdbarch, print_insn_green_dsp_v3);
	break;
  }
  
  if (tdesc_data)
    tdesc_use_registers (gdbarch, tdesc, std::move (tdesc_data));

  return gdbarch;
}

/* Register the above initialization routine.  */

void
_initialize_green_dsp_tdep ();

void
_initialize_green_dsp_tdep ()
{
  register_gdbarch_init (bfd_arch_green_dsp, green_dsp_gdbarch_init);
}
