#ifndef GREEN_DSP_OPCODES_H_INCLUDED
#define GREEN_DSP_OPCODES_H_INCLUDED

typedef enum {
  GREEN_DSP_Reg_None,
  GREEN_DSP_Reg_A0,
  GREEN_DSP_Reg_M0,
  GREEN_DSP_Reg_M1,
  GREEN_DSP_Reg_L0,
  GREEN_DSP_Reg_L1,
  GREEN_DSP_Reg_R0,
  GREEN_DSP_Reg_R1,
  GREEN_DSP_Reg_DP0,
  GREEN_DSP_Reg_DP1,
  GREEN_DSP_Reg_RP0,
  GREEN_DSP_Reg_PG0,
  GREEN_DSP_Reg_F0,
  GREEN_DSP_Reg_SP0,
  GREEN_DSP_Reg_PS0,
  GREEN_DSP_Reg_DS0,
  GREEN_DSP_Reg_SS0,
  GREEN_DSP_Reg_Num_Registers,
} GREEN_DSP_Register;

typedef enum
{
  GDSP_V2_unknown,
  GDSP_V2_NOP,
  GDSP_V2_MOV,
  GDSP_V2_MUX,
  GDSP_V2_ADD,
  GDSP_V2_ADD3,
  GDSP_V2_SUB,
  GDSP_V2_MUX_ADD,
  GDSP_V2_MUX_ADD3,
  GDSP_V2_MUX_SUB,
  GDSP_V2_MUX_CLAMP,
  GDSP_V2_CLAMP_ADD,
  GDSP_V2_CLAMP_ADD3,
  GDSP_V2_CLAMP_SUB,
  GDSP_V2_MUX_CLAMP_ADD,
  GDSP_V2_MUX_CLAMP_ADD3,
  GDSP_V2_MUX_CLAMP_SUB,
  GDSP_V2_CLAMP,
  GDSP_V2_CMP,
  GDSP_V2_OUT,
  GDSP_V2_IN,
  GDSP_V2_STOP,
  GDSP_V2_OR,
  GDSP_V2_AND,
  GDSP_V2_XOR,
  GDSP_V2_NOT,
  GDSP_V2_ABS,
  GDSP_V2_SFT_RL,
  GDSP_V2_SFT_RA,
  GDSP_V2_SFT_LL,
  GDSP_V2_SFT_LA,
  GDSP_V2_PUSH,
  GDSP_V2_POP,
  GDSP_V2_RET,
  GDSP_V2_MUX_R,
  GDSP_V2_ADD_R,
  GDSP_V2_SUB_R,
  GDSP_V2_MUX_ADD_R,
  GDSP_V2_MUX_SUB_R,
  GDSP_V2_ABS_S,
  GDSP_V2_CMPX,
  GDSP_V2_CLI,
  GDSP_V2_STI,
  GDSP_V2_RETI,
  GDSP_V2_MOV_S,
  GDSP_V2_JSR,
  GDSP_V2_JMP,
  GDSP_V2_JMP_O,
  GDSP_V2_JMP_U,
  GDSP_V2_JMP_Z,
  GDSP_V2_JMP_NZ,
} GREEN_DSP_V2_Opcode_ID;

typedef enum
{
  GDSP_V3_unknown,
  GDSP_V3_NOP,
  GDSP_V3_MOV,
  GDSP_V3_MUX,
  GDSP_V3_ADD,
  GDSP_V3_ADD3,
  GDSP_V3_SUB,
  GDSP_V3_MUX_ADD,
  GDSP_V3_MUX_ADD3,
  GDSP_V3_MUX_SUB,
  GDSP_V3_MUX_CLAMP,
  GDSP_V3_CLAMP_ADD,
  GDSP_V3_CLAMP_ADD3,
  GDSP_V3_CLAMP_SUB,
  GDSP_V3_MUX_CLAMP_ADD,
  GDSP_V3_MUX_CLAMP_ADD3,
  GDSP_V3_MUX_CLAMP_SUB,
  GDSP_V3_CLAMP,
  GDSP_V3_CMP,
  GDSP_V3_OUT,
  GDSP_V3_IN,
  GDSP_V3_STOP,
  GDSP_V3_OR,
  GDSP_V3_AND,
  GDSP_V3_XOR,
  GDSP_V3_NOT,
  GDSP_V3_ABS,
  GDSP_V3_SFT_RL,
  GDSP_V3_SFT_RA,
  GDSP_V3_SFT_LL,
  GDSP_V3_SFT_LA,
  GDSP_V3_PUSH,
  GDSP_V3_POP,
  GDSP_V3_RET,
  GDSP_V3_MUX_R,
  GDSP_V3_ADD_R,
  GDSP_V3_SUB_R,
  GDSP_V3_MUX_ADD_R,
  GDSP_V3_MUX_SUB_R,
  GDSP_V3_ABS_S,
  GDSP_V3_CMPX,
  GDSP_V3_CLI,
  GDSP_V3_STI,
  GDSP_V3_RETI,
  GDSP_V3_INC,
  GDSP_V3_DEC,
  GDSP_V3_DIV,
  GDSP_V3_MOVP,
  GDSP_V3_BTEST,
  GDSP_V3_FLGTEST,
  GDSP_V3_FLGSET,
  GDSP_V3_FLGCLR,
  GDSP_V3_CLAMP_U,
  GDSP_V3_CMP_U,
  GDSP_V3_CMPX_U,
  GDSP_V3_MOV_S,
  GDSP_V3_JSR,
  GDSP_V3_JMP,
  GDSP_V3_JMP_O,
  GDSP_V3_JMP_U,
  GDSP_V3_JMP_Z,
  GDSP_V3_JMP_NZ,
} GREEN_DSP_V3_Opcode_ID;

typedef enum {
  GREEN_DSP_Operand_None = 0,
  GREEN_DSP_Operand_Immediate,	/* #addend */
  GREEN_DSP_Operand_Register,	/* reg */
  GREEN_DSP_Operand_Register_dec,	/* (reg-) */
  GREEN_DSP_Operand_Register_inc,	/* (reg+) */
} GREEN_DSP_Operand_Type;

typedef struct {
  GREEN_DSP_Operand_Type operandType;
  GREEN_DSP_Register	   reg;
  int              addend;
} GREEN_DSP_Opcode_Operand;

typedef struct
{
  int lineno;
  union
  {
	  GREEN_DSP_V2_Opcode_ID green_dsp_v2_opcode_ID;
	  GREEN_DSP_V3_Opcode_ID green_dsp_v3_opcode_ID;
  } green_dsp_Opcode_ID;
  //unsigned		flags:8; /* PSW mask, for side effects only */
  int			n_bytes;
  char *		syntax;
  //GREEN_DSP_Size		size;
  /* By convention, these are destination, source.  */
  GREEN_DSP_Opcode_Operand	op[3];
} GREEN_DSP_Opcode_Decoded;

typedef enum
{
	GREEN_DSP_v2_type,
	GREEN_DSP_faa_type,
	GREEN_DSP_v3_type
} GREEN_DSP_Core_Type;

int green_dsp_decode_opcode (GREEN_DSP_Core_Type core, unsigned long, GREEN_DSP_Opcode_Decoded *, int (*)(void *), void *);

#endif
