#line 1 "green_dsp-decode.opc"
#include "sysdep.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "ansidecl.h"
#include "opcode/green_dsp.h"

static int trace = 0;

typedef struct
{
  GREEN_DSP_Opcode_Decoded * green_dsp;
  int (* getbyte)(void *);
  void * ptr;
  unsigned char * op;
} LocalData;

#define UNSUPPORTED() \
  green_dsp->syntax = "*unknown*"

#define ID(x) \
	switch(core) \
	{ \
	case GREEN_DSP_v2_type: \
	case GREEN_DSP_faa_type: \
		green_dsp->green_dsp_Opcode_ID.green_dsp_v2_opcode_ID = GDSP_V2_##x; \
		break; \
	case GREEN_DSP_v3_type: \
		green_dsp->green_dsp_Opcode_ID.green_dsp_v3_opcode_ID = GDSP_V3_##x; \
		break; \
	} \
	green_dsp->lineno = __LINE__
	
#define ID_NO_V2(x) \
	switch(core) \
	{ \
	case GREEN_DSP_v2_type: \
	case GREEN_DSP_faa_type: \	
		green_dsp->green_dsp_Opcode_ID.green_dsp_v2_opcode_ID = GDSP_V2_unknown; \
		break; \
	case GREEN_DSP_v3_type: \
		green_dsp->green_dsp_Opcode_ID.green_dsp_v3_opcode_ID = GDSP_V3_##x; \
		break; \
	} \
	green_dsp->lineno = __LINE__
	
	
#define OP(n,t,r,a) (green_dsp->op[n].operandType = t, \
		     green_dsp->op[n].reg = r,	     \
		     green_dsp->op[n].addend = a )

#define OP0R(xreg) OP(0, GREEN_DSP_Operand_Register, GREEN_DSP_Reg_##xreg, 0)
#define OP1R(xreg) OP(1, GREEN_DSP_Operand_Register, GREEN_DSP_Reg_##xreg, 0)
#define OP2R(xreg) OP(2, GREEN_DSP_Operand_Register, GREEN_DSP_Reg_##xreg, 0)
#define OP0RINC(xreg) OP(0, GREEN_DSP_Operand_Register_inc, GREEN_DSP_Reg_##xreg, 0)
#define OP1RINC(xreg) OP(1, GREEN_DSP_Operand_Register_inc, GREEN_DSP_Reg_##xreg, 0)
#define OP0RDEC(xreg) OP(0, GREEN_DSP_Operand_Register_dec, GREEN_DSP_Reg_##xreg, 0)
#define OP1RDEC(xreg) OP(1, GREEN_DSP_Operand_Register_dec, GREEN_DSP_Reg_##xreg, 0)
#define OP0IMM(val) OP(0, GREEN_DSP_Operand_Immediate, GREEN_DSP_Reg_None, val)
#define OP1IMM(val) OP(1, GREEN_DSP_Operand_Immediate, GREEN_DSP_Reg_None, val)


#define AU ATTRIBUTE_UNUSED
#define GETBYTE() (ld->op [ld->green_dsp->n_bytes++] = ld->getbyte (ld->ptr))
#define B ((unsigned long) GETBYTE())

#define SYNTAX(x) green_dsp->syntax = x

int
green_dsp_decode_opcode (GREEN_DSP_Core_Type core, unsigned long pc AU,
		  GREEN_DSP_Opcode_Decoded * green_dsp,
		  int (* getbyte)(void *),
		  void * ptr)
{
  LocalData lds, * ld = &lds;
  unsigned char op_buf[20] = {0};
  unsigned char *op = op_buf;
  int op0, op1;

  lds.green_dsp = green_dsp;
  lds.getbyte = getbyte;
  lds.ptr = ptr;
  lds.op = op;

  memset (green_dsp, 0, sizeof (*green_dsp));

/*----------------------------------------------------------------------*/

  GETBYTE ();
  switch (op[0] & 0xff)
  {
    case 0x00:
        {
          /** 0000 0000			nop			*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0000			nop			*/",
                     op[0]);
            }
          SYNTAX("nop");
#line 90 "green_dsp-decode.opc"
          ID(NOP);
        
        }
      break;
    case 0x01:
        {
          /** 0000 0001			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0001			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 93 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1R(M0);
          
        }
      break;
    case 0x02:
        {
          /** 0000 0010			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0010			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 96 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1R(M1);
          
        }
      break;
    case 0x03:
        {
          /** 0000 0011			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0011			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 99 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1R(R0);
          
        }
      break;
    case 0x04:
        {
          /** 0000 0100			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0100			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 102 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0R(A0); OP1R(R1);
          
        }
      break;
    case 0x05:
        {
          /** 0000 0101			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0101			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 105 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1R(L0);
          
        }
      break;
    case 0x06:
        {
          /** 0000 0110			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0110			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 108 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1R(L1);
         
        }
      break;
    case 0x07:
        {
          /** 0000 0111			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 0111			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 111 "green_dsp-decode.opc"
          ID(MOV); OP0RINC(DP0); OP1R(A0);
          
        }
      break;
    case 0x08:
        {
          /** 0000 1000			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1000			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 114 "green_dsp-decode.opc"
          ID(MOV); OP0RINC(DP1); OP1R(M0);
          
        }
      break;
    case 0x09:
        {
          /** 0000 1001			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1001			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 117 "green_dsp-decode.opc"
          ID(MOV); OP0RINC(DP1); OP1R(M1);
          
        }
      break;
    case 0x0a:
        {
          /** 0000 1010			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1010			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 120 "green_dsp-decode.opc"
          ID(MOV); OP0RINC(DP1); OP1R(R0);
          
        }
      break;
    case 0x0b:
        {
          /** 0000 1011			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1011			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 123 "green_dsp-decode.opc"
          ID(MOV); OP0RINC(DP1); OP1R(L0);
          
        }
      break;
    case 0x0c:
        {
          /** 0000 1100			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1100			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 126 "green_dsp-decode.opc"
          ID(MOV); OP0RINC(DP1); OP1R(L1);
          
        }
      break;
    case 0x0d:
        {
          /** 0000 1101			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1101			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 129 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1RINC(RP0);
          
        }
      break;
    case 0x0e:
        {
          /** 0000 1110			mux				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1110			mux				*/",
                     op[0]);
            }
          SYNTAX("mux");
#line 132 "green_dsp-decode.opc"
          ID(MUX);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("mul");
          }
          
        }
      break;
    case 0x0f:
        {
          /** 0000 1111			add				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0000 1111			add				*/",
                     op[0]);
            }
          SYNTAX("add");
#line 139 "green_dsp-decode.opc"
          ID(ADD);
        
        }
      break;
    case 0x10:
        {
          /** 0001 0000			add3				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0000			add3				*/",
                     op[0]);
            }
          SYNTAX("add3");
#line 142 "green_dsp-decode.opc"
          ID_NO_V2(ADD3);
          
        }
      break;
    case 0x11:
        {
          /** 0001 0001			sub				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0001			sub				*/",
                     op[0]);
            }
          SYNTAX("sub");
#line 145 "green_dsp-decode.opc"
          ID(SUB);
          
        }
      break;
    case 0x12:
        {
          /** 0001 0010			mux_add				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0010			mux_add				*/",
                     op[0]);
            }
          SYNTAX("mux_add");
#line 148 "green_dsp-decode.opc"
          ID(MUX_ADD);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("mul_add");
          }
          
        }
      break;
    case 0x13:
        {
          /** 0001 0011			mux_add3				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0011			mux_add3				*/",
                     op[0]);
            }
          SYNTAX("mux_add3");
#line 155 "green_dsp-decode.opc"
          ID_NO_V2(MUX_ADD3);
          
        }
      break;
    case 0x14:
        {
          /** 0001 0100			mux_sub				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0100			mux_sub				*/",
                     op[0]);
            }
          SYNTAX("mux_sub");
#line 158 "green_dsp-decode.opc"
          ID(MUX_SUB);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("mul_sub");
          }
          
        }
      break;
    case 0x15:
        {
          /** 0001 0101			mux_clamp				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0101			mux_clamp				*/",
                     op[0]);
            }
          SYNTAX("mux_clamp");
#line 165 "green_dsp-decode.opc"
          ID_NO_V2(MUX_CLAMP);
          
        }
      break;
    case 0x16:
        {
          /** 0001 0110			clamp_add				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0110			clamp_add				*/",
                     op[0]);
            }
          SYNTAX("clamp_add");
#line 168 "green_dsp-decode.opc"
          ID_NO_V2(CLAMP_ADD);
          
        }
      break;
    case 0x17:
        {
          /** 0001 0111			clamp_add3				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 0111			clamp_add3				*/",
                     op[0]);
            }
          SYNTAX("clamp_add3");
#line 171 "green_dsp-decode.opc"
          ID_NO_V2(CLAMP_ADD3);
          
        }
      break;
    case 0x18:
        {
          /** 0001 1000			clamp_sub				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 1000			clamp_sub				*/",
                     op[0]);
            }
          SYNTAX("clamp_sub");
#line 174 "green_dsp-decode.opc"
          ID_NO_V2(CLAMP_SUB);
          
        }
      break;
    case 0x19:
        {
          /** 0001 1001			mux_clamp_add				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 1001			mux_clamp_add				*/",
                     op[0]);
            }
          SYNTAX("mux_clamp_add");
#line 177 "green_dsp-decode.opc"
          ID_NO_V2(MUX_CLAMP_ADD);
          
        }
      break;
    case 0x1a:
        {
          /** 0001 1010			mux_clamp_add3				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 1010			mux_clamp_add3				*/",
                     op[0]);
            }
          SYNTAX("mux_clamp_add3");
#line 180 "green_dsp-decode.opc"
          ID_NO_V2(MUX_CLAMP_ADD3);
          
        }
      break;
    case 0x1b:
        {
          /** 0001 1011			mux_clamp_sub				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 1011			mux_clamp_sub				*/",
                     op[0]);
            }
          SYNTAX("mux_clamp_sub");
#line 183 "green_dsp-decode.opc"
          ID_NO_V2(MUX_CLAMP_SUB);
          
        }
      break;
    case 0x1c:
        {
          /** 0001 1100			clamp				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 1100			clamp				*/",
                     op[0]);
            }
          SYNTAX("clamp");
#line 186 "green_dsp-decode.opc"
          ID(CLAMP);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("limit");
          }
          
        }
      break;
    case 0x1d:
        {
          /** 0001 1101			cmp	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0001 1101			cmp	%0				*/",
                     op[0]);
            }
          SYNTAX("cmp	%0");
#line 193 "green_dsp-decode.opc"
          ID(CMP); OP0RINC(DP0);
          
        }
      break;
    case 0x1e:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0001 1110 immh imml 			out	%0, (%1)				*/
#line 196 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 196 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0001 1110 immh imml 			out	%0, (%1)				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("out	%0, (%1)");
#line 196 "green_dsp-decode.opc"
                ID(OUT); OP0R(A0); OP1IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x1f:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0001 1111 immh imml 			in (%0), %1				*/
#line 199 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 199 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0001 1111 immh imml 			in (%0), %1				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("in (%0), %1");
#line 199 "green_dsp-decode.opc"
                ID(IN); OP0IMM((immh << 4) | imml); OP1R(A0);
                
              }
            break;
        }
      break;
    case 0x20:
        {
          /** 0010 0000  			stop				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0000  			stop				*/",
                     op[0]);
            }
          SYNTAX("stop");
#line 202 "green_dsp-decode.opc"
          ID(STOP);
          
        /*----------------------------------------------------------------------*/
          
        }
      break;
    case 0x21:
        {
          /** 0010 0001  			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0001  			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 207 "green_dsp-decode.opc"
          ID(MOV); OP0RDEC(DP0); OP1R(A0);
          
        }
      break;
    case 0x22:
        {
          /** 0010 0010  			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0010  			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 210 "green_dsp-decode.opc"
          ID(MOV); OP0R(A0); OP1RDEC(RP0);
          
        }
      break;
    case 0x23:
        {
          /** 0010 0011  			or	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0011  			or	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("or	%0, %1");
#line 213 "green_dsp-decode.opc"
          ID(OR); OP0R(A0); OP1R(R0);
          
        }
      break;
    case 0x24:
        {
          /** 0010 0100  			and	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0100  			and	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("and	%0, %1");
#line 216 "green_dsp-decode.opc"
          ID(AND); OP0R(A0); OP1R(R0);
          
        }
      break;
    case 0x25:
        {
          /** 0010 0101  			xor	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0101  			xor	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("xor	%0, %1");
#line 219 "green_dsp-decode.opc"
          ID(XOR); OP0R(A0); OP1R(R0);
          
        }
      break;
    case 0x26:
        {
          /** 0010 0110  			not	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0110  			not	%0				*/",
                     op[0]);
            }
          SYNTAX("not	%0");
#line 222 "green_dsp-decode.opc"
          ID(NOT); OP0R(A0);
          
        }
      break;
    case 0x27:
        {
          /** 0010 0111  			abs	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 0111  			abs	%0				*/",
                     op[0]);
            }
          SYNTAX("abs	%0");
#line 225 "green_dsp-decode.opc"
          ID(ABS); OP0R(A0);
          
        }
      break;
    case 0x28:
        {
          /** 0010 1000  			sft_rl				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1000  			sft_rl				*/",
                     op[0]);
            }
          SYNTAX("sft_rl");
#line 228 "green_dsp-decode.opc"
          ID(SFT_RL);
          
        }
      break;
    case 0x29:
        {
          /** 0010 1001  			sft_ra				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1001  			sft_ra				*/",
                     op[0]);
            }
          SYNTAX("sft_ra");
#line 231 "green_dsp-decode.opc"
          ID(SFT_RA);
          
        }
      break;
    case 0x2a:
        {
          /** 0010 1010  			sft_ll				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1010  			sft_ll				*/",
                     op[0]);
            }
          SYNTAX("sft_ll");
#line 234 "green_dsp-decode.opc"
          ID(SFT_LL);
          
        }
      break;
    case 0x2b:
        {
          /** 0010 1011  			sft_la				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1011  			sft_la				*/",
                     op[0]);
            }
          SYNTAX("sft_la");
#line 237 "green_dsp-decode.opc"
          ID(SFT_LA);
          
        }
      break;
    case 0x2c:
        {
          /** 0010 1100  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1100  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 240 "green_dsp-decode.opc"
          ID(PUSH); OP0R(A0);
          
        }
      break;
    case 0x2d:
        {
          /** 0010 1101  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1101  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 243 "green_dsp-decode.opc"
          ID(PUSH); OP0R(M0);
          
        }
      break;
    case 0x2e:
        {
          /** 0010 1110  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1110  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 246 "green_dsp-decode.opc"
          ID(PUSH); OP0R(M1);
          
        }
      break;
    case 0x2f:
        {
          /** 0010 1111  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0010 1111  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 249 "green_dsp-decode.opc"
          ID(PUSH); OP0R(R0);
          
        }
      break;
    case 0x30:
        {
          /** 0011 0000  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0000  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 252 "green_dsp-decode.opc"
          ID(PUSH); OP0R(L0);
          
        }
      break;
    case 0x31:
        {
          /** 0011 0001  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0001  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 255 "green_dsp-decode.opc"
          ID(PUSH); OP0R(L1);
          
        }
      break;
    case 0x32:
        {
          /** 0011 0010  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0010  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 258 "green_dsp-decode.opc"
          ID(PUSH); OP0R(DP0);
          
        }
      break;
    case 0x33:
        {
          /** 0011 0011  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0011  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 261 "green_dsp-decode.opc"
          ID(PUSH); OP0R(DP1);
        
        }
      break;
    case 0x34:
        {
          /** 0011 0100  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0100  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 264 "green_dsp-decode.opc"
          ID(PUSH); OP0R(RP0);
          
        }
      break;
    case 0x35:
        {
          /** 0011 0101  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0101  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 267 "green_dsp-decode.opc"
          ID(POP); OP0R(A0);
        
        }
      break;
    case 0x36:
        {
          /** 0011 0110  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0110  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 270 "green_dsp-decode.opc"
          ID(POP); OP0R(M0);
          
        }
      break;
    case 0x37:
        {
          /** 0011 0111  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 0111  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 273 "green_dsp-decode.opc"
          ID(POP); OP0R(M1);
          
        }
      break;
    case 0x38:
        {
          /** 0011 1000  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1000  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 276 "green_dsp-decode.opc"
          ID(POP); OP0R(R0);
          
        }
      break;
    case 0x39:
        {
          /** 0011 1001  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1001  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 279 "green_dsp-decode.opc"
          ID(POP); OP0R(L0);
          
        }
      break;
    case 0x3a:
        {
          /** 0011 1010  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1010  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 282 "green_dsp-decode.opc"
          ID(POP); OP0R(L1);
          
        }
      break;
    case 0x3b:
        {
          /** 0011 1011  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1011  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 285 "green_dsp-decode.opc"
          ID(POP); OP0R(DP0);
          
        }
      break;
    case 0x3c:
        {
          /** 0011 1100  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1100  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 288 "green_dsp-decode.opc"
          ID(POP); OP0R(DP1);
          
        }
      break;
    case 0x3d:
        {
          /** 0011 1101  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1101  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 291 "green_dsp-decode.opc"
          ID(POP); OP0R(RP0);
          
        }
      break;
    case 0x3e:
        {
          /** 0011 1110  			ret				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1110  			ret				*/",
                     op[0]);
            }
          SYNTAX("ret");
#line 294 "green_dsp-decode.opc"
          ID(RET);
        
        }
      break;
    case 0x3f:
        {
          /** 0011 1111  			push	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0011 1111  			push	%0				*/",
                     op[0]);
            }
          SYNTAX("push	%0");
#line 297 "green_dsp-decode.opc"
          ID_NO_V2(PUSH); OP0R(R1);
          
        }
      break;
    case 0x40:
        {
          /** 0100 0000  			pop	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 0000  			pop	%0				*/",
                     op[0]);
            }
          SYNTAX("pop	%0");
#line 300 "green_dsp-decode.opc"
          ID_NO_V2(POP); OP0R(R1);
          
        /*----------------------------------------------------------------------*/
        
        }
      break;
    case 0x41:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0001 immh imml  			mov	(%0, %1), %2				*/
#line 305 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 305 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0001 immh imml  			mov	(%0, %1), %2				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	(%0, %1), %2");
#line 305 "green_dsp-decode.opc"
                ID(MOV); OP0IMM((immh << 4) | imml); OP1R(DP0); OP2R(A0);
                
              }
            break;
        }
      break;
    case 0x42:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0010 immh imml  			mov	(%0, %1), %2				*/
#line 308 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 308 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0010 immh imml  			mov	(%0, %1), %2				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	(%0, %1), %2");
#line 308 "green_dsp-decode.opc"
                ID(MOV); OP0IMM((immh << 4) | imml); OP1R(DP1); OP2R(M0);
                
              }
            break;
        }
      break;
    case 0x43:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0011 immh imml  			mov	(%0, %1), %2				*/
#line 311 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 311 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0011 immh imml  			mov	(%0, %1), %2				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	(%0, %1), %2");
#line 311 "green_dsp-decode.opc"
                ID(MOV); OP0IMM((immh << 4) | imml); OP1R(DP1); OP2R(M1);
                
              }
            break;
        }
      break;
    case 0x44:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0100 immh imml  			mov	(%0, %1), %2				*/
#line 314 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 314 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0100 immh imml  			mov	(%0, %1), %2				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	(%0, %1), %2");
#line 314 "green_dsp-decode.opc"
                ID(MOV); OP0IMM((immh << 4) | imml); OP1R(DP1); OP2R(R0);
                
              }
            break;
        }
      break;
    case 0x45:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0101 immh imml  			mov	(%0, %1), %2				*/
#line 317 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 317 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0101 immh imml  			mov	(%0, %1), %2				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	(%0, %1), %2");
#line 317 "green_dsp-decode.opc"
                ID(MOV); OP0IMM((immh << 4) | imml); OP1R(DP1); OP2R(L0);
                
              }
            break;
        }
      break;
    case 0x46:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0110 immh imml  			mov	(%0, %1), %2				*/
#line 320 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 320 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0110 immh imml  			mov	(%0, %1), %2				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	(%0, %1), %2");
#line 320 "green_dsp-decode.opc"
                ID(MOV); OP0IMM((immh << 4) | imml); OP1R(DP1); OP2R(L1);
                
              }
            break;
        }
      break;
    case 0x47:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0100 0111 immh imml  			mov	%0, (%1, %2)				*/
#line 323 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 323 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0100 0111 immh imml  			mov	%0, (%1, %2)				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	%0, (%1, %2)");
#line 323 "green_dsp-decode.opc"
                ID(MOV); OP0R(A0); OP1IMM((immh << 4) | imml); OP2R(RP0);
                
              }
            break;
        }
      break;
    case 0x48:
        {
          /** 0100 1000  			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1000  			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 326 "green_dsp-decode.opc"
          ID(MOV); OP0R(SP0); OP1R(RP0);
          
        }
      break;
    case 0x49:
        {
          /** 0100 1001  			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1001  			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 329 "green_dsp-decode.opc"
          ID(MOV); OP0R(RP0); OP1R(SP0);
          
        }
      break;
    case 0x4a:
        {
          /** 0100 1010  			mux_r				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1010  			mux_r				*/",
                     op[0]);
            }
          SYNTAX("mux_r");
#line 332 "green_dsp-decode.opc"
          ID(MUX_R);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("mul_r");
          }
          
        }
      break;
    case 0x4b:
        {
          /** 0100 1011  			add_r				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1011  			add_r				*/",
                     op[0]);
            }
          SYNTAX("add_r");
#line 339 "green_dsp-decode.opc"
          ID(ADD_R);
          
        }
      break;
    case 0x4c:
        {
          /** 0100 1100  			sub_r				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1100  			sub_r				*/",
                     op[0]);
            }
          SYNTAX("sub_r");
#line 342 "green_dsp-decode.opc"
          ID(SUB_R);
          
        }
      break;
    case 0x4d:
        {
          /** 0100 1101  			mux_add_r				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1101  			mux_add_r				*/",
                     op[0]);
            }
          SYNTAX("mux_add_r");
#line 345 "green_dsp-decode.opc"
          ID(MUX_ADD_R);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("mul_add_r");
          }
          
        }
      break;
    case 0x4e:
        {
          /** 0100 1110  			mux_sub_r				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1110  			mux_sub_r				*/",
                     op[0]);
            }
          SYNTAX("mux_sub_r");
#line 352 "green_dsp-decode.opc"
          ID(MUX_SUB_R);
          if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
          {
        	SYNTAX("mul_sub_r");
          }
          
        }
      break;
    case 0x4f:
        {
          /** 0100 1111  			abs_s	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0100 1111  			abs_s	%0				*/",
                     op[0]);
            }
          SYNTAX("abs_s	%0");
#line 359 "green_dsp-decode.opc"
          ID(ABS_S); OP0R(A0);
          
        }
      break;
    case 0x50:
        {
          /** 0101 0000  			cmpx	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0000  			cmpx	%0				*/",
                     op[0]);
            }
          SYNTAX("cmpx	%0");
#line 362 "green_dsp-decode.opc"
          ID_NO_V2(CMPX); OP0RINC(DP0);
          
        }
      break;
    case 0x51:
        {
          /** 0101 0001  			cli				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0001  			cli				*/",
                     op[0]);
            }
          SYNTAX("cli");
#line 365 "green_dsp-decode.opc"
          ID(CLI);
          
        }
      break;
    case 0x52:
        {
          /** 0101 0010  			sti				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0010  			sti				*/",
                     op[0]);
            }
          SYNTAX("sti");
#line 368 "green_dsp-decode.opc"
          ID(STI);
          
        }
      break;
    case 0x54:
        {
          /** 0101 0100  			reti				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0100  			reti				*/",
                     op[0]);
            }
          SYNTAX("reti");
#line 371 "green_dsp-decode.opc"
          ID(RETI);
        
        /*----------------------------------------------------------------------*/
        
        }
      break;
    case 0x55:
        {
          /** 0101 0101  			inc	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0101  			inc	%0				*/",
                     op[0]);
            }
          SYNTAX("inc	%0");
#line 376 "green_dsp-decode.opc"
          ID_NO_V2(INC); OP0R(A0);
        
        }
      break;
    case 0x56:
        {
          /** 0101 0110  			dec	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0110  			dec	%0				*/",
                     op[0]);
            }
          SYNTAX("dec	%0");
#line 379 "green_dsp-decode.opc"
          ID_NO_V2(DEC); OP0R(A0);
          
        }
      break;
    case 0x57:
        {
          /** 0101 0111  			mov	(%0+%1), %2				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 0111  			mov	(%0+%1), %2				*/",
                     op[0]);
            }
          SYNTAX("mov	(%0+%1), %2");
#line 382 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0R(DP0); OP1R(R0); OP2R(A0);
          
        }
      break;
    case 0x58:
        {
          /** 0101 1000  			div				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 1000  			div				*/",
                     op[0]);
            }
          SYNTAX("div");
#line 385 "green_dsp-decode.opc"
          ID_NO_V2(DIV);
          
        }
      break;
    case 0x59:
        {
          /** 0101 1001  			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 1001  			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 388 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0R(A0); OP1R(F0);
          
        }
      break;
    case 0x5a:
        {
          /** 0101 1010  			mov	%0, %1				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0101 1010  			mov	%0, %1				*/",
                     op[0]);
            }
          SYNTAX("mov	%0, %1");
#line 391 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0R(F0); OP1R(A0);
          
        }
      break;
    case 0x60:
    case 0x61:
    case 0x62:
    case 0x63:
        {
          /** 0110 00im  			mov	#%0, %1				*/
#line 394 "green_dsp-decode.opc"
          int im AU = op[0] & 0x03;
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0110 00im  			mov	#%0, %1				*/",
                     op[0]);
              printf ("  im = 0x%x\n", im);
            }
          SYNTAX("mov	#%0, %1");
#line 394 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0IMM(im); OP1R(PS0);
          
        /* todo: PS0,DS0,SS0 in the other excel file*/
        }
      break;
    case 0x64:
    case 0x65:
    case 0x66:
    case 0x67:
        {
          /** 0110 01im  			movp	#%0, %1				*/
#line 398 "green_dsp-decode.opc"
          int im AU = op[0] & 0x03;
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0110 01im  			movp	#%0, %1				*/",
                     op[0]);
              printf ("  im = 0x%x\n", im);
            }
          SYNTAX("movp	#%0, %1");
#line 398 "green_dsp-decode.opc"
          ID_NO_V2(MOVP); OP0IMM(im); OP1R(PS0);
          
        }
      break;
    case 0x68:
    case 0x69:
    case 0x6a:
    case 0x6b:
        {
          /** 0110 10im  			mov	#%0, %1				*/
#line 401 "green_dsp-decode.opc"
          int im AU = op[0] & 0x03;
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0110 10im  			mov	#%0, %1				*/",
                     op[0]);
              printf ("  im = 0x%x\n", im);
            }
          SYNTAX("mov	#%0, %1");
#line 401 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0IMM(im); OP1R(DS0);
          
        }
      break;
    case 0x6c:
    case 0x6d:
    case 0x6e:
    case 0x6f:
        {
          /** 0110 11im  			mov	#%0, %1				*/
#line 404 "green_dsp-decode.opc"
          int im AU = op[0] & 0x03;
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0110 11im  			mov	#%0, %1				*/",
                     op[0]);
              printf ("  im = 0x%x\n", im);
            }
          SYNTAX("mov	#%0, %1");
#line 404 "green_dsp-decode.opc"
          ID_NO_V2(MOV); OP0IMM(im); OP1R(SS0);
        
        }
      break;
    case 0x70:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0000 immh imml  			sft_rl	#%0				*/
#line 407 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 407 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0000 immh imml  			sft_rl	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("sft_rl	#%0");
#line 407 "green_dsp-decode.opc"
                ID_NO_V2(SFT_RL); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x71:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0001 immh imml  			sft_ll	#%0				*/
#line 410 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 410 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0001 immh imml  			sft_ll	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("sft_ll	#%0");
#line 410 "green_dsp-decode.opc"
                ID_NO_V2(SFT_LL); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x72:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0010 immh imml  			btest	#%0				*/
#line 413 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 413 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0010 immh imml  			btest	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("btest	#%0");
#line 413 "green_dsp-decode.opc"
                ID_NO_V2(BTEST); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x73:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0011 immh imml  			flgtest	#%0				*/
#line 416 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 416 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0011 immh imml  			flgtest	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("flgtest	#%0");
#line 416 "green_dsp-decode.opc"
                ID_NO_V2(FLGTEST); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x74:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0100 immh imml  			flgset	#%0				*/
#line 419 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 419 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0100 immh imml  			flgset	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("flgset	#%0");
#line 419 "green_dsp-decode.opc"
                ID_NO_V2(FLGSET); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x75:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0101 immh imml  			flgclr	#%0				*/
#line 422 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 422 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0101 immh imml  			flgclr	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("flgclr	#%0");
#line 422 "green_dsp-decode.opc"
                ID_NO_V2(FLGCLR); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x76:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0110 immh imml  			sft_ra	#%0				*/
#line 425 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 425 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0110 immh imml  			sft_ra	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("sft_ra	#%0");
#line 425 "green_dsp-decode.opc"
                ID_NO_V2(SFT_RA); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x77:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
              {
                /** 0111 0111 immh imml  			sft_la	#%0				*/
#line 428 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 428 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 0111 0111 immh imml  			sft_la	#%0				*/",
                           op[0], op[1]);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("sft_la	#%0");
#line 428 "green_dsp-decode.opc"
                ID_NO_V2(SFT_LA); OP0IMM((immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0x78:
        {
          /** 0111 1000  			clamp unsigned				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0111 1000  			clamp unsigned				*/",
                     op[0]);
            }
          SYNTAX("clamp unsigned");
#line 431 "green_dsp-decode.opc"
          ID_NO_V2(CLAMP_U);
          
        }
      break;
    case 0x79:
        {
          /** 0111 1001  			cmp unsigned	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0111 1001  			cmp unsigned	%0				*/",
                     op[0]);
            }
          SYNTAX("cmp unsigned	%0");
#line 434 "green_dsp-decode.opc"
          ID_NO_V2(CMP_U); OP0RINC(DP0);
          
        }
      break;
    case 0x7a:
        {
          /** 0111 1010  			cmpx unsigned	%0				*/
          if (trace)
            {
              printf ("\033[33m%s\033[0m  %02x\n",
                     "/** 0111 1010  			cmpx unsigned	%0				*/",
                     op[0]);
            }
          SYNTAX("cmpx unsigned	%0");
#line 437 "green_dsp-decode.opc"
          ID_NO_V2(CMPX_U); OP0RINC(DP0);
          
        /*----------------------------------------------------------------------*/
        
        }
      break;
    case 0x80:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_1:
              {
                /** 1000 00im immh imml  			mov.s	#%0, %1				*/
#line 442 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 442 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 442 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1000 00im immh imml  			mov.s	#%0, %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	#%0, %1");
#line 442 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(DP0);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
                
              }
            break;
        }
      break;
    case 0x81:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_1;
            break;
        }
      break;
    case 0x82:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_1;
            break;
        }
      break;
    case 0x83:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_1;
            break;
        }
      break;
    case 0x84:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_2:
              {
                /** 1000 01im immh imml  			mov.s	#%0, %1				*/
#line 449 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 449 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 449 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1000 01im immh imml  			mov.s	#%0, %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	#%0, %1");
#line 449 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(DP1);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
                
              }
            break;
        }
      break;
    case 0x85:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_2;
            break;
        }
      break;
    case 0x86:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_2;
            break;
        }
      break;
    case 0x87:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_2;
            break;
        }
      break;
    case 0x88:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_3:
              {
                /** 1000 10im immh imml  			mov.s	#%0, %1				*/
#line 456 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 456 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 456 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1000 10im immh imml  			mov.s	#%0, %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	#%0, %1");
#line 456 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(RP0);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
               
              }
            break;
        }
      break;
    case 0x89:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_3;
            break;
        }
      break;
    case 0x8a:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_3;
            break;
        }
      break;
    case 0x8b:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_3;
            break;
        }
      break;
    case 0x8c:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_4:
              {
                /** 1000 11im immh imml  			mov.s	(#%0), %1				*/
#line 463 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 463 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 463 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1000 11im immh imml  			mov.s	(#%0), %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	(#%0), %1");
#line 463 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(A0);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
                
              }
            break;
        }
      break;
    case 0x8d:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_4;
            break;
        }
      break;
    case 0x8e:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_4;
            break;
        }
      break;
    case 0x8f:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_4;
            break;
        }
      break;
    case 0x90:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_5:
              {
                /** 1001 00im immh imml  			mov	#%0, %1				*/
#line 470 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 470 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 470 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1001 00im immh imml  			mov	#%0, %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov	#%0, %1");
#line 470 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(SP0);
                
              }
            break;
        }
      break;
    case 0x91:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_5;
            break;
        }
      break;
    case 0x92:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_5;
            break;
        }
      break;
    case 0x93:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_5;
            break;
        }
      break;
    case 0x94:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_6:
              {
                /** 1001 01im immh imml  			mov.s	(#%0), %1				*/
#line 473 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 473 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 473 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1001 01im immh imml  			mov.s	(#%0), %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	(#%0), %1");
#line 473 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(M0);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
                
              }
            break;
        }
      break;
    case 0x95:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_6;
            break;
        }
      break;
    case 0x96:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_6;
            break;
        }
      break;
    case 0x97:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_6;
            break;
        }
      break;
    case 0x98:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_7:
              {
                /** 1001 10im immh imml  			mov.s	(#%0), %1				*/
#line 480 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 480 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 480 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1001 10im immh imml  			mov.s	(#%0), %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	(#%0), %1");
#line 480 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(M1);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
                
              }
            break;
        }
      break;
    case 0x99:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_7;
            break;
        }
      break;
    case 0x9a:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_7;
            break;
        }
      break;
    case 0x9b:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_7;
            break;
        }
      break;
    case 0x9c:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_8:
              {
                /** 1001 11im immh imml  			mov.s	(#%0), %1				*/
#line 487 "green_dsp-decode.opc"
                int im AU = op[0] & 0x03;
#line 487 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 487 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1001 11im immh imml  			mov.s	(#%0), %1				*/",
                           op[0], op[1]);
                    printf ("  im = 0x%x,", im);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("mov.s	(#%0), %1");
#line 487 "green_dsp-decode.opc"
                ID(MOV_S); OP0IMM((im << 10) | (immh << 6) | (imml << 2)); OP1R(R0);
                if ((core == GREEN_DSP_v2_type) || (core == GREEN_DSP_faa_type))
                {
              	SYNTAX("mov #%0, %1");
                }
                
              }
            break;
        }
      break;
    case 0x9d:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_8;
            break;
        }
      break;
    case 0x9e:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_8;
            break;
        }
      break;
    case 0x9f:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_8;
            break;
        }
      break;
    case 0xa0:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_9:
              {
                /** 1010 imhh immh imml  			jsr	#%0				*/
#line 494 "green_dsp-decode.opc"
                int imhh AU = op[0] & 0x0f;
#line 494 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 494 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1010 imhh immh imml  			jsr	#%0				*/",
                           op[0], op[1]);
                    printf ("  imhh = 0x%x,", imhh);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("jsr	#%0");
#line 494 "green_dsp-decode.opc"
                ID(JSR); OP0IMM((imhh << 8) | (immh << 4) | imml);
              
              }
            break;
        }
      break;
    case 0xa1:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa2:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa3:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa4:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa5:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa6:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa7:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa8:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xa9:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xaa:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xab:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xac:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xad:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xae:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xaf:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_9;
            break;
        }
      break;
    case 0xb0:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_10:
              {
                /** 1011 imhh immh imml  			jmp	#%0				*/
#line 497 "green_dsp-decode.opc"
                int imhh AU = op[0] & 0x0f;
#line 497 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 497 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1011 imhh immh imml  			jmp	#%0				*/",
                           op[0], op[1]);
                    printf ("  imhh = 0x%x,", imhh);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("jmp	#%0");
#line 497 "green_dsp-decode.opc"
                ID(JMP); OP0IMM((imhh << 8) | (immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0xb1:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb2:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb3:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb4:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb5:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb6:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb7:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb8:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xb9:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xba:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xbb:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xbc:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xbd:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xbe:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xbf:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_10;
            break;
        }
      break;
    case 0xc0:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_11:
              {
                /** 1100 imhh immh imml  			jmp	over, #%0				*/
#line 500 "green_dsp-decode.opc"
                int imhh AU = op[0] & 0x0f;
#line 500 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 500 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1100 imhh immh imml  			jmp	over, #%0				*/",
                           op[0], op[1]);
                    printf ("  imhh = 0x%x,", imhh);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("jmp	over, #%0");
#line 500 "green_dsp-decode.opc"
                ID(JMP_O); OP0IMM((imhh << 8) | (immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0xc1:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc2:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc3:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc4:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc5:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc6:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc7:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc8:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xc9:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xca:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xcb:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xcc:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xcd:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xce:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xcf:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_11;
            break;
        }
      break;
    case 0xd0:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_12:
              {
                /** 1101 imhh immh imml  			jmp	under, #%0				*/
#line 503 "green_dsp-decode.opc"
                int imhh AU = op[0] & 0x0f;
#line 503 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 503 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1101 imhh immh imml  			jmp	under, #%0				*/",
                           op[0], op[1]);
                    printf ("  imhh = 0x%x,", imhh);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("jmp	under, #%0");
#line 503 "green_dsp-decode.opc"
                ID(JMP_U); OP0IMM((imhh << 8) | (immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0xd1:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd2:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd3:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd4:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd5:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd6:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd7:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd8:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xd9:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xda:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xdb:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xdc:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xdd:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xde:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xdf:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_12;
            break;
        }
      break;
    case 0xe0:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_13:
              {
                /** 1110 imhh immh imml  			jmp	zero, #%0				*/
#line 506 "green_dsp-decode.opc"
                int imhh AU = op[0] & 0x0f;
#line 506 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 506 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1110 imhh immh imml  			jmp	zero, #%0				*/",
                           op[0], op[1]);
                    printf ("  imhh = 0x%x,", imhh);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("jmp	zero, #%0");
#line 506 "green_dsp-decode.opc"
                ID(JMP_Z); OP0IMM((imhh << 8) | (immh << 4) | imml);
                
              }
            break;
        }
      break;
    case 0xe1:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe2:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe3:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe4:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe5:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe6:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe7:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe8:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xe9:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xea:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xeb:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xec:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xed:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xee:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xef:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_13;
            break;
        }
      break;
    case 0xf0:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            op_semantics_14:
              {
                /** 1111 imhh immh imml  			jmp	not_zero, #%0				*/
#line 509 "green_dsp-decode.opc"
                int imhh AU = op[0] & 0x0f;
#line 509 "green_dsp-decode.opc"
                int immh AU = (op[1] >> 4) & 0x0f;
#line 509 "green_dsp-decode.opc"
                int imml AU = op[1] & 0x0f;
                if (trace)
                  {
                    printf ("\033[33m%s\033[0m  %02x %02x\n",
                           "/** 1111 imhh immh imml  			jmp	not_zero, #%0				*/",
                           op[0], op[1]);
                    printf ("  imhh = 0x%x,", imhh);
                    printf ("  immh = 0x%x,", immh);
                    printf ("  imml = 0x%x\n", imml);
                  }
                SYNTAX("jmp	not_zero, #%0");
#line 509 "green_dsp-decode.opc"
                ID(JMP_NZ); OP0IMM((imhh << 8) | (immh << 4) | imml);
              
              }
            break;
        }
      break;
    case 0xf1:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf2:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf3:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf4:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf5:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf6:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf7:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf8:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xf9:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xfa:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xfb:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xfc:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xfd:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xfe:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    case 0xff:
        GETBYTE ();
        switch (op[1] & 0x00)
        {
          case 0x00:
            goto op_semantics_14;
            break;
        }
      break;
    default: UNSUPPORTED(); break;
  }
#line 512 "green_dsp-decode.opc"

  return green_dsp->n_bytes;
}
