/* Disassembler code for Renesas RL78.
   Copyright (C) 2011-2015 Free Software Foundation, Inc.
   Contributed by Red Hat.
   Written by DJ Delorie.

   This file is part of the GNU opcodes library.

   This library is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   It is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

#include "sysdep.h"
#include <stdio.h>

#include "bfd.h"
#include "dis-asm.h"
#include "opcode/green_dsp.h"

typedef struct
{
  bfd_vma pc;
  disassemble_info * dis;
} GREEN_DSP_Data;

static int
green_dsp_get_byte (void * vdata)
{
  bfd_byte buf[1];
  GREEN_DSP_Data *green_dsp_data = (GREEN_DSP_Data *) vdata;

  green_dsp_data->dis->read_memory_func (green_dsp_data->pc,
				  buf,
				  1,
				  green_dsp_data->dis);

  green_dsp_data->pc ++;
  return buf[0];
}

static char const *
register_names[] =
{
  "",
  "A0",
  "M0",
  "M1",
  "L0",
  "L1",
  "R0",
  "R1",
  "DP0",
  "DP1",
  "RP0",
  "PG0",
  "F0",
  "SP0",
  "PS0",
  "DS0",
  "SS0",
};

#define PR (dis->fprintf_func)
#define PS (dis->stream)
#define PC(c) PR (PS, "%c", c)

static int
print_insn_green_dsp (bfd_vma addr, disassemble_info * dis, GREEN_DSP_Core_Type green_dsp_core_type)
{
  int rv;
  GREEN_DSP_Data green_dsp_data;
  GREEN_DSP_Opcode_Decoded opcode;
  const char * s;

  green_dsp_data.pc = addr;
  green_dsp_data.dis = dis;

  rv = green_dsp_decode_opcode (green_dsp_core_type, addr, &opcode, green_dsp_get_byte, &green_dsp_data);

  dis->bytes_per_line = 10;

  s = opcode.syntax;

  for (; *s; s++)
  {
	  if (*s != '%')
	  {
		  PC (*s);
	  }
      else
      {
    	  GREEN_DSP_Opcode_Operand * oper;

    	  s++;

    	  oper = (*s == '0')? &opcode.op[0] : ((*s == '1')? &opcode.op[1] : &opcode.op[2]);

    	  switch(oper->operandType)
    	  {
    	  case GREEN_DSP_Operand_Immediate:
    		  PR (PS, "%d", oper->addend);
    		  break;
    	  case GREEN_DSP_Operand_Register:
     		  PR (PS, "%s", register_names[oper->reg]);
        	  break;
    	  case GREEN_DSP_Operand_Register_dec:
     		  PR (PS, "(%s-)", register_names[oper->reg]);
        	  break;
    	  case GREEN_DSP_Operand_Register_inc:
     		  PR (PS, "(%s+)", register_names[oper->reg]);
        	  break;
    	  }

      }
  }

  return rv;
}

int
print_insn_green_dsp_v2 (bfd_vma addr, disassemble_info * dis)
{
	return print_insn_green_dsp(addr, dis, GREEN_DSP_v2_type);
}

int
print_insn_green_dsp_v3 (bfd_vma addr, disassemble_info * dis)
{
	return print_insn_green_dsp(addr, dis, GREEN_DSP_v3_type);
}
